Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit 1c50968


[ROCm/hip commit: 32e11e7dc6]
This commit is contained in:
Alex Voicu
2017-11-29 21:49:10 +00:00
والد cd61d38118
کامیت 8d51eaafb6
63فایلهای تغییر یافته به همراه171 افزوده شده و 173 حذف شده
@@ -1307,9 +1307,9 @@ namespace
__global__
void hip_fill_n(RandomAccessIterator f, N n, T value)
{
const uint32_t grid_dim = hipGridDim_x * hipBlockDim_x;
const uint32_t grid_dim = gridDim.x * blockDim.x;
size_t idx = hipBlockIdx_x * block_dim + hipThreadIdx_x;
size_t idx = blockIdx.x * block_dim + threadIdx.x;
while (idx < n) {
__builtin_memcpy(
reinterpret_cast<void*>(&f[idx]),